#!/usr/bin/env python
"""
===============================================================
Run all existiong test
===============================================================
"""

__author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
__version__ = "$Revision: 2 $"
__date__ = "$Date: 2010/02/07 $"
__copyright__ = ""
__license__ = "GPLv2"


import unittest

import sys
sys.path.append("..")

from LdmTest import LdmTest                 #IGNORE:W0611
from ProfileTest import ProfileTest         #IGNORE:W0611
from SqlDriverTest import SqlDriverTest     #IGNORE:W0611
from StructureTest import StructureTest     #IGNORE:W0611
from MessageTest import MessageTest         #IGNORE:W0611
from AccountTest import AccountTest         #IGNORE:W0611
#from MiscTest import MiscTest               #IGNORE:W0611

if __name__ == '__main__':
    unittest.main()
